[compiler-rt] [Darwin][ASan][Test] Create a noinlined wrapper function for reliable suppression in test. (PR #131247)

via llvm-commits llvm-commits at lists.llvm.org
Thu Mar 13 17:47:19 PDT 2025


llvmbot wrote:


<!--LLVM PR SUMMARY COMMENT-->

@llvm/pr-subscribers-compiler-rt-sanitizer

Author: Paddy McDonald (padriff)

<details>
<summary>Changes</summary>

CFStringCreateWithBytes may not always appear on stack due to optimizations. Create a wrapper function for the purposes of testing suppression files that will always appear on stack for test stability.

Also necessary to disable leaks to pass on Apple Silicon.

rdar://144800068


---
Full diff: https://github.com/llvm/llvm-project/pull/131247.diff


1 Files Affected:

- (modified) compiler-rt/test/asan/TestCases/Darwin/suppressions-sandbox.cpp (+10-5) 


``````````diff
diff --git a/compiler-rt/test/asan/TestCases/Darwin/suppressions-sandbox.cpp b/compiler-rt/test/asan/TestCases/Darwin/suppressions-sandbox.cpp
index 966f21346e4fe..50dfd1e2e332b 100644
--- a/compiler-rt/test/asan/TestCases/Darwin/suppressions-sandbox.cpp
+++ b/compiler-rt/test/asan/TestCases/Darwin/suppressions-sandbox.cpp
@@ -3,8 +3,8 @@
 // RUN: not %run %t 2>&1 | FileCheck --check-prefix=CHECK-CRASH %s
 
 // Check that suppressing a function name works within a no-fork sandbox
 // RUN: echo "interceptor_via_fun:CFStringCreateWithBytes" > %t.supp
 // RUN: %env_asan_opts=suppressions='"%t.supp"' \
 // RUN:   sandbox-exec -p '(version 1)(allow default)(deny process-fork)' \
 // RUN:   %run %t 2>&1 | FileCheck --check-prefix=CHECK-IGNORE %s
 
@@ -13,12 +13,17 @@
 
 #include <CoreFoundation/CoreFoundation.h>
 
+// Use a noinline + disable_tail_calls wrapper function to suppress to stabilize test.
+__attribute__((noinline)) __attribute__((disable_tail_calls)) CFStringRef
+createCFString(const unsigned char *bytes, CFIndex length) {
+  return CFStringCreateWithBytes(kCFAllocatorDefault, bytes, length,
+                                 kCFStringEncodingUTF8, FALSE);
+}
+
 int main() {
   char *a = (char *)malloc(6);
   strcpy(a, "hello");
-  CFStringRef str =
-      CFStringCreateWithBytes(kCFAllocatorDefault, (unsigned char *)a, 10,
-                              kCFStringEncodingUTF8, FALSE);  // BOOM
+  CFStringRef str = createCFString((unsigned char *)a, 10); // BOOM
   fprintf(stderr, "Ignored.\n");
   free(a);
   CFRelease(str);
@@ -3,8 +3,8 @@
 
 // Check that suppressing a function name works within a no-fork sandbox
-// RUN: echo "interceptor_via_fun:CFStringCreateWithBytes" > %t.supp
-// RUN: %env_asan_opts=suppressions='"%t.supp"' \
+// RUN: echo "interceptor_via_fun:createCFString" > %t.supp
+// RUN: %env_asan_opts=suppressions='"%t.supp"':verbostiy=1:  \
 // RUN:   sandbox-exec -p '(version 1)(allow default)(deny process-fork)' \
 // RUN:   %run %t 2>&1 | FileCheck --check-prefix=CHECK-IGNORE %s

``````````

</details>


https://github.com/llvm/llvm-project/pull/131247


More information about the llvm-commits mailing list